Package: GenABEL
Type: Package
Title: genome-wide SNP association analysis
Version: 1.8-0
Date: 2013-12-09
Author: GenABEL project developers
Contact: GenABEL project developers <genabel.project at gmail.com>
Maintainer: Yurii Aulchenko <yurii@bionet.nsc.ru>
Depends: R (>= 2.15.0), methods, MASS, utils, GenABEL.data
Suggests: qvalue, genetics, haplo.stats, DatABEL (>= 0.9-0), hglm,
        MetABEL, PredictABEL, VariABEL, bigRR
Description: a package for genome-wide association analysis between 
             quantitative or binary traits and single-nucleotide
             polymorphisms (SNPs). 
License: GPL (>= 2)
URL: http://www.genabel.org, http://forum.genabel.org,
        http://genabel.r-forge.r-project.org/
BugReports: http://r-forge.r-project.org/tracker/?group_id=505
Packaged: 2013-12-26 05:48:08 UTC; maksim
NeedsCompilation: yes
Repository: CRAN
Date/Publication: 2013-12-27 14:47:02
Built: R 3.5.1; x86_64-w64-mingw32; 2018-11-23 17:03:19 UTC; windows
Archs: x64
